@@ -2,8 +2,9 @@ package db_client
 
 import (
 	"context"
+	"fmt"
 	"log"
-	"sort"
+	"strings"
 	"sync"
 
 	"github.com/jackc/pgx/v5"
@@ -12,38 +13,35 @@ import (
 	"github.com/turbot/steampipe/pkg/constants"
 	"github.com/turbot/steampipe/pkg/db/db_common"
 	"github.com/turbot/steampipe/pkg/error_helpers"
-	"github.com/turbot/steampipe/pkg/schema"
 	"github.com/turbot/steampipe/pkg/steampipeconfig"
 	"github.com/turbot/steampipe/pkg/utils"
+	"golang.org/x/exp/maps"
 	"golang.org/x/sync/semaphore"
 )
 
 // DbClient wraps over `sql.DB` and gives an interface to the database
 type DbClient struct {
-	connectionString          string
-	pool                      *pgxpool.Pool
-	requiredSessionSearchPath []string
+	connectionString string
+	pool             *pgxpool.Pool
+
+	// this flag is set if the service that this client
+	// is connected to is running in the same physical system
+	isLocalService bool
 
 	// concurrency management for db session access
 	parallelSessionInitLock *semaphore.Weighted
 
-	// a wait group which lets others wait for any running DBSession init to complete
-	sessionInitWaitGroup *sync.WaitGroup
-
 	// map of database sessions, keyed to the backend_pid in postgres
 	// used to update session search path where necessary
 	sessions map[uint32]*db_common.DatabaseSession
 	// allows locked access to the 'sessions' map
 	sessionsMutex *sync.Mutex
 
-	// list of connection schemas
-	foreignSchemaNames []string
-	// list of all local schemas
-	allSchemaNames []string
-
 	// if a custom search path or a prefix is used, store it here
 	customSearchPath []string
 	searchPathPrefix []string
+	// the default user search path
+	userSearchPath []string
 	// a cached copy of (viper.GetBool(constants.ArgTiming) && viper.GetString(constants.ArgOutput) == constants.OutputFormatTable)
 	// (cached to avoid concurrent access error on viper)
 	showTimingFlag bool
@@ -68,9 +66,6 @@ func NewDbClient(ctx context.Context, connectionString string, onConnectionCallb
 	}
 
 	client := &DbClient{
-		// a waitgroup to keep track of active session initializations
-		// so that we don't try to shutdown while an init is underway
-		sessionInitWaitGroup: wg,
 		// a weighted semaphore to control the maximum number parallel
 		// initializations under way
 		parallelSessionInitLock: semaphore.NewWeighted(constants.MaxParallelClientInits),
@@ -85,8 +80,14 @@ func NewDbClient(ctx context.Context, connectionString string, onConnectionCallb
 		return nil, err
 	}
 
-	// populate foreign schema names - this wil be updated whenever we acquire a session or refresh connections
-	if err := client.LoadSchemaNames(ctx); err != nil {
+	// set user search path
+	err := client.LoadUserSearchPath(ctx)
+	if err != nil {
+		return nil, err
+	}
+
+	// populate customSearchPath
+	if err := client.SetRequiredSessionSearchPath(ctx); err != nil {
 		client.Close(ctx)
 		return nil, err
 	}
@@ -115,7 +116,6 @@ func (c *DbClient) shouldShowTiming() bool {
 func (c *DbClient) Close(context.Context) error {
 	log.Printf("[TRACE] DbClient.Close %v", c.pool)
 	if c.pool != nil {
-		c.sessionInitWaitGroup.Wait()
 		// clear the sessions map - so that we can't reuse it
 		c.sessions = nil
 		c.pool.Close()
@@ -124,66 +124,95 @@ func (c *DbClient) Close(context.Context) error {
 	return nil
 }
 
-// ForeignSchemaNames implements Client
-func (c *DbClient) ForeignSchemaNames() []string {
-	return c.foreignSchemaNames
-}
-
-// AllSchemaNames implements Client
-func (c *DbClient) AllSchemaNames() []string {
-	return c.allSchemaNames
-}
-
-// LoadSchemaNames implements Client
-func (c *DbClient) LoadSchemaNames(ctx context.Context) error {
-	res, err := c.pool.Query(ctx, "SELECT DISTINCT foreign_table_schema FROM information_schema.foreign_tables")
-	if err != nil {
-		return err
-	}
-	// clear foreign schemas
-	var foreignSchemaNames []string
-	var schema string
-	for res.Next() {
-		if err := res.Scan(&schema); err != nil {
-			return err
-		}
-		// ignore command schema
-		if schema != constants.CommandSchema {
-			foreignSchemaNames = append(foreignSchemaNames, schema)
-		}
-	}
-	c.foreignSchemaNames = foreignSchemaNames
-
-	res, err = c.pool.Query(ctx, "SELECT schema_name FROM information_schema.schemata WHERE schema_name NOT LIKE 'pg_%' ORDER BY schema_name;")
-	if err != nil {
-		return err
-	}
-	var allSchemaNames []string
-	for res.Next() {
-		if err := res.Scan(&schema); err != nil {
-			return err
-		}
-		// ignore command schema
-		allSchemaNames = append(allSchemaNames, schema)
-	}
-	c.allSchemaNames = allSchemaNames
-
-	return nil
-}
-
 // RefreshSessions terminates the current connections and creates a new one - repopulating session data
-func (c *DbClient) RefreshSessions(ctx context.Context) *db_common.AcquireSessionResult {
+func (c *DbClient) RefreshSessions(ctx context.Context) (res *db_common.AcquireSessionResult) {
 	utils.LogTime("db_client.RefreshSessions start")
 	defer utils.LogTime("db_client.RefreshSessions end")
 
 	if err := c.refreshDbClient(ctx); err != nil {
-		return &db_common.AcquireSessionResult{Error: err}
+		res.Error = err
+		return res
 	}
-	sessionResult := c.AcquireSession(ctx)
-	if sessionResult.Session != nil {
-		sessionResult.Session.Close(error_helpers.IsContextCanceled(ctx))
+	res = c.AcquireSession(ctx)
+	if res.Session != nil {
+		res.Session.Close(error_helpers.IsContextCanceled(ctx))
 	}
-	return sessionResult
+	return res
+}
+
+// GetSchemaFromDB  retrieves schemas for all steampipe connections (EXCEPT DISABLED CONNECTIONS)
+// NOTE: it optimises the schema extraction by extracting schema information for
+// connections backed by distinct plugins and then fanning back out.
+func (c *DbClient) GetSchemaFromDB(ctx context.Context) (*db_common.SchemaMetadata, error) {
+	conn, _, err := c.GetDatabaseConnectionWithRetries(ctx)
+	if err != nil {
+		return nil, err
+	}
+	defer conn.Release()
+
+	// for optimisation purposes, try to load connection state and build a map of schemas to load
+	// (if we are connected to a remote server running an older CLI,
+	// this load may fail, in which case bypass the optimisation)
+	connectionStateMap, err := steampipeconfig.LoadConnectionState(ctx, conn.Conn(), steampipeconfig.WithWaitUntilLoading())
+	// NOTE: if we failed to load conenction state, this may be because we are connected to an older version of the CLI
+	// use legacy (v0.19.x) schema loading code
+	if err != nil {
+		return c.GetSchemaFromDBLegacy(ctx, conn)
+	}
+
+	// build a ConnectionSchemaMap object to identify the schemas to load
+	connectionSchemaMap := steampipeconfig.NewConnectionSchemaMap(ctx, connectionStateMap, c.GetRequiredSessionSearchPath())
+	if err != nil {
+		return nil, err
+	}
+
+	// get the unique schema - we use this to limit the schemas we load from the database
+	schemas := maps.Keys(connectionSchemaMap)
+
+	// build a query to retrieve these schemas
+	query := c.buildSchemasQuery(schemas...)
+
+	//execute
+	tablesResult, err := conn.Query(ctx, query)
+	if err != nil {
+		return nil, err
+	}
+
+	// build schema metadata from query result
+	metadata, err := db_common.BuildSchemaMetadata(tablesResult)
+	if err != nil {
+		return nil, err
+	}
+
+	// we now need to add in all other schemas which have the same schemas as those we have loaded
+	for loadedSchema, otherSchemas := range connectionSchemaMap {
+		// all 'otherSchema's have the same schema as loadedSchema
+		exemplarSchema, ok := metadata.Schemas[loadedSchema]
+		if !ok {
+			// should can happen in the case of a dynamic plugin with no tables - use empty schema
+			exemplarSchema = make(map[string]db_common.TableSchema)
+		}
+
+		for _, s := range otherSchemas {
+			metadata.Schemas[s] = exemplarSchema
+		}
+	}
+
+	return metadata, nil
+}
+
+func (c *DbClient) GetSchemaFromDBLegacy(ctx context.Context, conn *pgxpool.Conn) (*db_common.SchemaMetadata, error) {
+	// build a query to retrieve these schemas
+	query := c.buildSchemasQueryLegacy()
+
+	//execute
+	tablesResult, err := conn.Query(ctx, query)
+	if err != nil {
+		return nil, err
+	}
+
+	// build schema metadata from query result
+	return db_common.BuildSchemaMetadata(tablesResult)
 }
 
 // refreshDbClient terminates the current connection and opens up a new connection to the service.
@@ -191,9 +220,6 @@ func (c *DbClient) refreshDbClient(ctx context.Context) error {
 	utils.LogTime("db_client.refreshDbClient start")
 	defer utils.LogTime("db_client.refreshDbClient end")
 
-	// wait for any pending inits to finish
-	c.sessionInitWaitGroup.Wait()
-
 	// close the connection pool and recreate
 	c.pool.Close()
 	if err := c.establishConnectionPool(ctx); err != nil {
@@ -203,64 +229,43 @@ func (c *DbClient) refreshDbClient(ctx context.Context) error {
 	return nil
 }
 
-// RefreshConnectionAndSearchPaths implements Client
-func (c *DbClient) RefreshConnectionAndSearchPaths(ctx context.Context, _ ...string) *steampipeconfig.RefreshConnectionResult {
-	// base db client does not refresh connections, it just sets search path
-	// (only local db client refreshed connections)
-	res := &steampipeconfig.RefreshConnectionResult{}
-	if err := c.SetRequiredSessionSearchPath(ctx); err != nil {
-		res.Error = err
+func (c *DbClient) buildSchemasQuery(schemas ...string) string {
+	for idx, s := range schemas {
+		schemas[idx] = fmt.Sprintf("'%s'", s)
 	}
-	return res
+
+	// build the schemas filter clause
+	schemaClause := ""
+	if len(schemas) > 0 {
+		schemaClause = fmt.Sprintf(`
+    cols.table_schema in (%s)
+	OR`, strings.Join(schemas, ","))
+	}
+
+	query := fmt.Sprintf(`
+SELECT
+		table_name,
+		column_name,
+		column_default,
+		is_nullable,
+		data_type,
+		udt_name,
+		table_schema,
+		(COALESCE(pg_catalog.col_description(c.oid, cols.ordinal_position :: int),'')) as column_comment,
+		(COALESCE(pg_catalog.obj_description(c.oid),'')) as table_comment
+FROM
+    information_schema.columns cols
+LEFT JOIN
+    pg_catalog.pg_namespace nsp ON nsp.nspname = cols.table_schema
+LEFT JOIN
+    pg_catalog.pg_class c ON c.relname = cols.table_name AND c.relnamespace = nsp.oid
+WHERE %s
+	LEFT(cols.table_schema,8) = 'pg_temp_'
+`, schemaClause)
+	return query
 }
+func (c *DbClient) buildSchemasQueryLegacy() string {
 
-// GetSchemaFromDB requests for all columns of tables backed by steampipe plugins
-// and creates golang struct representations from the result
-func (c *DbClient) GetSchemaFromDB(ctx context.Context) (*schema.Metadata, error) {
-	utils.LogTime("db_client.GetSchemaFromDB start")
-	defer utils.LogTime("db_client.GetSchemaFromDB end")
-	connection, err := c.pool.Acquire(ctx)
-	error_helpers.FailOnError(err)
-
-	query := c.buildSchemasQuery()
-
-	tablesResult, err := connection.Query(ctx, query)
-	if err != nil {
-		return nil, err
-	}
-
-	metadata, err := db_common.BuildSchemaMetadata(tablesResult)
-	if err != nil {
-		return nil, err
-	}
-	connection.Release()
-
-	searchPath, err := c.GetCurrentSearchPath(ctx)
-	if err != nil {
-		return nil, err
-	}
-	metadata.SearchPath = searchPath
-
-	return metadata, nil
-}
-
-// GetDefaultSearchPath builds default search path from the connection schemas, book-ended with public and internal
-func (c *DbClient) GetDefaultSearchPath(ctx context.Context) []string {
-	// get foreign schema names
-	searchPath := c.foreignSchemaNames
-
-	sort.Strings(searchPath)
-	// add the 'public' schema as the first schema in the search_path. This makes it
-	// easier for users to build and work with their own tables, and since it's normally
-	// empty, doesn't make using steampipe tables any more difficult.
-	searchPath = append([]string{"public"}, searchPath...)
-	// add 'internal' schema as last schema in the search path
-	searchPath = append(searchPath, constants.FunctionSchema)
-
-	return searchPath
-}
-
-func (c *DbClient) buildSchemasQuery() string {
 	query := `
 WITH distinct_schema AS (
 	SELECT DISTINCT(foreign_table_schema) 
