@@ -1,16 +1,18 @@
 package modinstaller
 
 import (
+	"context"
 	"github.com/turbot/go-kit/helpers"
+	"github.com/turbot/steampipe/pkg/error_helpers"
 	"github.com/turbot/steampipe/pkg/utils"
 )
 
-func InstallWorkspaceDependencies(opts *InstallOpts) (_ *InstallData, err error) {
+func InstallWorkspaceDependencies(ctx context.Context, opts *InstallOpts) (_ *InstallData, err error) {
 	utils.LogTime("cmd.InstallWorkspaceDependencies")
 	defer func() {
 		utils.LogTime("cmd.InstallWorkspaceDependencies end")
 		if r := recover(); r != nil {
-			err = helpers.ToError(r)
+			error_helpers.ShowError(ctx, helpers.ToError(r))
 		}
 	}()
 
@@ -20,7 +22,7 @@ func InstallWorkspaceDependencies(opts *InstallOpts) (_ *InstallData, err error)
 		return nil, err
 	}
 
-	if err := installer.InstallWorkspaceDependencies(); err != nil {
+	if err := installer.InstallWorkspaceDependencies(ctx); err != nil {
 		return nil, err
 	}
 
