@@ -18,6 +18,15 @@ func (l *DashboardEdgeList) Merge(other DashboardEdgeList) {
 	}
 }
 
+func (l *DashboardEdgeList) Get(name string) *DashboardEdge {
+	for _, n := range *l {
+		if n.Name() == name {
+			return n
+		}
+	}
+	return nil
+}
+
 func (l *DashboardEdgeList) Names() []string {
 	res := make([]string, len(*l))
 	for i, e := range *l {
@@ -25,3 +34,12 @@ func (l *DashboardEdgeList) Names() []string {
 	}
 	return res
 }
+
+func (l *DashboardEdgeList) Contains(other *DashboardEdge) bool {
+	for _, e := range *l {
+		if e == other {
+			return true
+		}
+	}
+	return false
+}
