@@ -31,8 +31,8 @@ func (d *DashboardTreeItemDiffs) AddRemovedItem(name string) {
 
 func (d *DashboardTreeItemDiffs) populateChildDiffs(old ModTreeItem, new ModTreeItem) {
 	// build map of child names
-	oldChildMap := make(map[string]bool)
-	newChildMap := make(map[string]bool)
+	oldChildMap := make(map[string]ModTreeItem)
+	newChildMap := make(map[string]ModTreeItem)
 
 	oldChildren := old.GetChildren()
 	newChildren := new.GetChildren()
@@ -42,19 +42,37 @@ func (d *DashboardTreeItemDiffs) populateChildDiffs(old ModTreeItem, new ModTree
 		if i < len(newChildren) && newChildren[i].Name() != child.Name() {
 			d.AddPropertyDiff("Children")
 		}
-		oldChildMap[child.Name()] = true
+		oldChildMap[child.Name()] = child
 	}
 	for _, child := range newChildren {
-		newChildMap[child.Name()] = true
+		newChildMap[child.Name()] = child
 	}
 
-	for childName := range oldChildMap {
-		if !newChildMap[childName] {
+	for childName, prevChild := range oldChildMap {
+		if child, existInNew := newChildMap[childName]; !existInNew {
 			d.AddRemovedItem(childName)
+		} else {
+			// so this resource exists on old and new
+
+			// TACTICAL
+			// some child resources are not added to the mod but we must consider them for the diff
+			var childDiff = &DashboardTreeItemDiffs{}
+			switch t := child.(type) {
+			case *DashboardWith:
+				childDiff = t.Diff(prevChild.(*DashboardWith))
+			case *DashboardNode:
+				childDiff = t.Diff(prevChild.(*DashboardNode))
+			case *DashboardEdge:
+				childDiff = t.Diff(prevChild.(*DashboardEdge))
+			}
+			if childDiff.HasChanges() {
+				d.AddPropertyDiff("Children")
+			}
+
 		}
 	}
 	for childName := range newChildMap {
-		if !oldChildMap[childName] {
+		if _, existsInOld := oldChildMap[childName]; !existsInOld {
 			d.AddAddedItem(childName)
 		}
 	}
@@ -110,13 +128,49 @@ func (d *DashboardTreeItemDiffs) queryProviderDiff(l QueryProvider, r QueryProvi
 	if len(lParams) != len(rParams) {
 		d.AddPropertyDiff("Params")
 	} else {
-		for i, p := range lParams {
-			if !p.Equals(rParams[i]) {
+		for i, lParam := range lParams {
+			if !lParam.Equals(rParams[i]) {
 				d.AddPropertyDiff("Params")
 			}
 		}
 	}
 
+	// with
+	if lwp, ok := l.(WithProvider); ok {
+		rwp := r.(WithProvider)
+		lWiths := lwp.GetWiths()
+		rWiths := rwp.GetWiths()
+		if len(lWiths) != len(rWiths) {
+			d.AddPropertyDiff("With")
+		} else {
+			for i, lWith := range lWiths {
+				if !lWith.Equals(rWiths[i]) {
+					d.AddPropertyDiff("With")
+				}
+			}
+		}
+
+		// have BASE withs changed
+		lbase := l.GetBase()
+		rbase := r.GetBase()
+		var lbaseWiths []*DashboardWith
+		var rbaseWiths []*DashboardWith
+		if lbase != nil {
+			lbaseWiths = lbase.(WithProvider).GetWiths()
+		}
+		if rbase != nil {
+			rbaseWiths = rbase.(WithProvider).GetWiths()
+		}
+		if len(lbaseWiths) != len(rbaseWiths) {
+			d.AddPropertyDiff("With")
+		} else {
+			for i, lBaseWith := range lbaseWiths {
+				if !lBaseWith.Equals(rbaseWiths[i]) {
+					d.AddPropertyDiff("With")
+				}
+			}
+		}
+	}
 }
 
 func (d *DashboardTreeItemDiffs) dashboardLeafNodeDiff(l DashboardLeafNode, r DashboardLeafNode) {
