@@ -1,7 +1,8 @@
 package versionmap
 
 import (
-	"github.com/Masterminds/semver"
+	"github.com/Masterminds/semver/v3"
+	"github.com/turbot/steampipe/pkg/steampipeconfig/modconfig"
 )
 
 type ResolvedVersionConstraint struct {
@@ -31,3 +32,7 @@ func (c ResolvedVersionConstraint) Equals(other *ResolvedVersionConstraint) bool
 func (c ResolvedVersionConstraint) IsPrerelease() bool {
 	return c.Version.Prerelease() != "" || c.Version.Metadata() != ""
 }
+
+func (c ResolvedVersionConstraint) DependencyPath() string {
+	return modconfig.BuildModDependencyPath(c.Name, c.Version)
+}
