@@ -6,19 +6,15 @@ import (
 	"sort"
 	"strings"
 
-	"github.com/turbot/steampipe/pkg/steampipeconfig/versionmap"
-
-	"github.com/Masterminds/semver"
-
+	"github.com/Masterminds/semver/v3"
 	"github.com/turbot/steampipe/pkg/constants"
-	"github.com/turbot/steampipe/pkg/ociinstaller"
 	"github.com/turbot/steampipe/pkg/plugin"
 	"github.com/turbot/steampipe/pkg/utils"
 )
 
 func (w *Workspace) CheckRequiredPluginsInstalled() error {
 	// get the list of all installed plugins
-	installedPlugins, err := w.getInstalledPlugins()
+	installedPlugins, err := plugin.GetInstalledPlugins()
 	if err != nil {
 		return err
 	}
@@ -35,7 +31,7 @@ func (w *Workspace) CheckRequiredPluginsInstalled() error {
 		if installedVersion, found := installedPlugins[name]; found {
 			req.SetInstalledVersion(installedVersion)
 
-			if installedPlugins[name].LessThan(requiredVersion) {
+			if !requiredVersion.Check(installedPlugins[name]) {
 				pluginsNotInstalled = append(pluginsNotInstalled, req)
 			}
 		} else {
@@ -51,48 +47,28 @@ func (w *Workspace) CheckRequiredPluginsInstalled() error {
 	return nil
 }
 
-func (w *Workspace) ValidateSteampipeVersion() error {
-	return w.Mod.ValidateSteampipeVersion()
-}
-
-func (w *Workspace) getRequiredPlugins() map[string]*semver.Version {
+func (w *Workspace) getRequiredPlugins() map[string]*semver.Constraints {
 	if w.Mod.Require != nil {
 		requiredPluginVersions := w.Mod.Require.Plugins
-		requiredVersion := make(versionmap.VersionMap)
+		requiredVersion := make(map[string]*semver.Constraints)
 		for _, pluginVersion := range requiredPluginVersions {
-			requiredVersion[pluginVersion.ShortName()] = pluginVersion.Version
+			requiredVersion[pluginVersion.ShortName()] = pluginVersion.Constraint
 		}
 		return requiredVersion
 	}
 	return nil
 }
 
-func (w *Workspace) getInstalledPlugins() (versionmap.VersionMap, error) {
-	installedPlugins := make(versionmap.VersionMap)
-	installedPluginsData, _ := plugin.List(nil)
-	for _, plugin := range installedPluginsData {
-		org, name, _ := ociinstaller.NewSteampipeImageRef(plugin.Name).GetOrgNameAndStream()
-		semverVersion, err := semver.NewVersion(plugin.Version)
-		if err != nil {
-			continue
-		}
-		pluginShortName := fmt.Sprintf("%s/%s", org, name)
-		installedPlugins[pluginShortName] = semverVersion
-	}
-	return installedPlugins, nil
-}
-
 type requiredPluginVersion struct {
 	plugin           string
 	requiredVersion  string
 	installedVersion string
 }
 
-func (v *requiredPluginVersion) SetRequiredVersion(requiredVersion *semver.Version) {
+func (v *requiredPluginVersion) SetRequiredVersion(requiredVersion *semver.Constraints) {
 	requiredVersionString := requiredVersion.String()
-	// if no required version was specified, the version will be 0.0.0
-	if requiredVersionString == "0.0.0" {
-		v.requiredVersion = "latest"
+	if requiredVersion == nil {
+		v.requiredVersion = "*"
 	} else {
 		v.requiredVersion = requiredVersionString
 	}
